[PATCH v2 1/6] Extend device_platform_driver macro

Alexander Shiyan shc_work at mail.ru
Sun Mar 10 01:41:30 EST 2013


This patch extends device_platform_driver macro, so now we allow
use it with various init levels and subsystems.

Signed-off-by: Alexander Shiyan <shc_work at mail.ru>
---
 include/driver.h | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/include/driver.h b/include/driver.h
index 46c56c0..138eab4 100644
--- a/include/driver.h
+++ b/include/driver.h
@@ -395,16 +395,19 @@ extern struct bus_type platform_bus;
 
 int platform_driver_register(struct driver_d *drv);
 
 /* device_platform_driver() - Helper macro for drivers that don't do
  * anything special in module registration. This eliminates a lot of
  * boilerplate. Each module may only use this macro once.
  */
-#define device_platform_driver(drv)			\
-	static int __init drv ## _register(void)	\
+#define register_driver_macro(level,bus,drv)		\
+	static int __init drv##_register(void)		\
 	{						\
-		return platform_driver_register(&drv);	\
+		return bus##_driver_register(&drv);	\
 	}						\
-	device_initcall(drv ## _register)
+	level##_initcall(drv##_register)
+
+#define device_platform_driver(drv)	\
+	register_driver_macro(device,platform,drv)
 
 int platform_device_register(struct device_d *new_device);
 
@@ -395,16 +395,19 @@ extern struct bus_type platform_bus;
 int platform_driver_register(struct driver_d *drv);
 
-/* device_platform_driver() - Helper macro for drivers that don't do
+/* register_driver_macro() - Helper macro for drivers that don't do
  * anything special in module registration. This eliminates a lot of
  * boilerplate. Each module may only use this macro once.
-- 
1.7.12.4




More information about the barebox mailing list